from setuptools import setup

setup(
    name='phdaysdefc',
    packages=['phdaysdefc'],
    description='This package will be replaced by pip due to dependancy confusion',
    version='10000.1',
    author='nguna',
    author_email='nishaanth@appknox.com'
)
